AMIMSpy
=======
|Build Status| |Build Status (AppVeyor)| |codecov| |License| |RTD doc| |Git|

Python package for processing acoustic mist ionization mass spectrometry-based metabolomics and lipidomics data

- **Documentation:** https://amimspy.readthedocs.io/en/latest
- **Source:** https://github.com/computational-metabolomics/amimspy
- **Bug reports:** https://github.com/computational-metabolomics/amimspy/issues


Installation
------------
See the `Installation page <https://amimspy.readthedocs.io/en/latest/installation.html>`__ of
the `online documentation <https://amimspy.readthedocs.io/en/latest/>`__.


Bug reports
-----------
Please report any bugs that you find `here <https://github.com/computational-metabolomics/amimspy/issues>`_.
Or fork the repository on `GitHub <https://github.com/computational-metabolomics/amimspy/>`_
and create a pull request (PR). We welcome all contributions, and we
will help you to make the PR if you are new to `git`.


Credits
-------

**Developers and contributers**
 - Matthew Smith (mjs708@student.bham.ac.uk) - `University of Birmingham (UK) <https://www.birmingham.ac.uk/>`__
 - Ralf J. M. Weber (r.j.weber@bham.ac.uk) - `University of Birmingham (UK) <https://www.birmingham.ac.uk/staff/profiles/biosciences/weber-ralf.aspx>`__

**AMIMSpy acknowledges support from the following funders:**
 - BBSRC and Waters Corporation for an iCASE PhD studentship.


License
--------
AMIMSpy is licensed under the GNU General Public License v3.0 (see `LICENSE file <https://github.com/computational-metabolomics/amimspy/blob/master/LICENSE>`_ for licensing information). Copyright © 2020 Matthew Smith, Ralf Weber


.. |Build Status| image:: https://github.com/computational-metabolomics/amimspy/workflows/amimspy/badge.svg
   :target: https://github.com/computational-metabolomics/amimspy/actions

.. |Build Status (AppVeyor)| image:: https://img.shields.io/appveyor/ci/RJMW/amimspy.svg?logo=appveyor&style=flat-square&maxAge=600
   :target: https://ci.appveyor.com/project/RJMW/amimspy/branch/master

.. |Git| image:: https://img.shields.io/badge/repository-GitHub-blue.svg?style=flat&maxAge=3600
   :target: https://github.com/computational-metabolomics/amimspy

.. |License| image:: https://img.shields.io/badge/License-GPLv3-blue.svg
   :target: https://www.gnu.org/licenses/gpl-3.0.html

.. |RTD doc| image:: https://img.shields.io/badge/documentation-RTD-71B360.svg?style=flat&maxAge=3600
   :target: https://amimspy.readthedocs.io/en/latest/
   
.. |codecov| image:: https://codecov.io/gh/computational-metabolomics/amimspy/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/computational-metabolomics/amimspy
